==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PieSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { PieSliceDataContextDescription } from "./PieSliceDataContextDescription";
/**
 * @hidden
 */
export let PieSliceDataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class PieSliceDataContextDescriptionMetadata extends Base {
        static b(a) {
            if (PieSliceDataContextDescriptionMetadata.a == null) {
                PieSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PieSliceDataContextDescriptionMetadata.c(PieSliceDataContextDescriptionMetadata.a);
            }
            if (a.j(PieSliceDataContextDescriptionMetadata.a)) {
                return;
            }
            a.y(PieSliceDataContextDescriptionMetadata.a);
        }
        static c(a) {
            DataContextDescriptionMetadata.c(a);
            a.item("PercentValue", "Number:double");
            a.item("IsOthersSlice", "Boolean");
        }
        static d(a) {
            PieSliceDataContextDescriptionMetadata.b(a);
            a.aa("PieSliceDataContext", () => new PieSliceDataContextDescription());
            a.z("PieSliceDataContext", PieSliceDataContextDescriptionMetadata.a);
        }
    }
    PieSliceDataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(PieSliceDataContextDescriptionMetadata, 'PieSliceDataContextDescriptionMetadata');
    PieSliceDataContextDescriptionMetadata.a = null;
    return PieSliceDataContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PieSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { PieSliceDataContextDescription } from "./PieSliceDataContextDescription";
/**
 * @hidden
 */
export let PieSliceDataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class PieSliceDataContextDescriptionMetadata extends Base {
        static b(a) {
            if (PieSliceDataContextDescriptionMetadata.a == null) {
                PieSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PieSliceDataContextDescriptionMetadata.c(PieSliceDataContextDescriptionMetadata.a);
            }
            if (a.k(PieSliceDataContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(PieSliceDataContextDescriptionMetadata.a);
        }
        static c(a) {
            DataContextDescriptionMetadata.c(a);
            a.item("PercentValue", "Number:double");
            a.item("IsOthersSlice", "Boolean");
        }
        static d(a) {
            PieSliceDataContextDescriptionMetadata.b(a);
            a.ac("PieSliceDataContext", () => new PieSliceDataContextDescription());
            a.ab("PieSliceDataContext", PieSliceDataContextDescriptionMetadata.a);
        }
    }
    PieSliceDataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(PieSliceDataContextDescriptionMetadata, 'PieSliceDataContextDescriptionMetadata');
    PieSliceDataContextDescriptionMetadata.a = null;
    return PieSliceDataContextDescriptionMetadata;
})();
